@@ -3,40 +3,39 @@
 #' @description
 #' Returns row counts of the dataset. If bare column names are provided, `count.()` returns counts by group.
 #'
-#' @param .data A data.frame or data.table
+#' @param .df A data.frame or data.table
 #' @param ... Columns to group by. `tidyselect` compatible.
 #'
 #' @export
 #' @md
 #'
 #' @examples
-#' example_df <- tidytable(
+#' test_df <- data.table(
 #'   x = 1:3,
 #'   y = 4:6,
 #'   z = c("a", "a", "b"))
 #'
-#' example_df %>%
+#' test_df %>%
 #'   count.()
 #'
-#' example_df %>%
+#' test_df %>%
 #'   count.(z)
 #'
-#' example_df %>%
-#'   count.(is.character)
-count. <- function(.data, ...) {
+#' test_df %>%
+#'   count.(where(is.character))
+count. <- function(.df, ...) {
   UseMethod("count.")
 }
 
 #' @export
-count..data.frame <- function(.data, ...) {
+count..data.frame <- function(.df, ...) {
 
-  .data <- as_tidytable(.data)
+  .df <- as_tidytable(.df)
 
-  by <- dots_selector_by(.data, ...)
+  by <- enquos(...)
+
+  summarize.(.df, N = .N, by = c(!!!by))
 
-  eval_expr(
-    .data[, list(N = .N), by = !!by]
-  )
 }
 
 #' @export
