@@ -15,32 +15,33 @@
 #' @export
 #'
 #' @examples
-#' example_dt <- data.table::data.table(
+#' test_df <- data.table(
 #'   x = c(1,1,1),
 #'   y = c(2,2,2),
 #'   z = c("a", "a", "b"))
 #'
-#' example_dt %>%
-#'   mutate_across.(is.numeric, as.character)
+#' test_df %>%
+#'   mutate_across.(where(is.numeric), as.character)
 #'
-#' example_dt %>%
+#' test_df %>%
 #'   mutate_across.(c(x, y), ~ .x * 2)
 #'
-#' example_dt %>%
-#'   mutate_across.(everything.(), as.character)
+#' test_df %>%
+#'   mutate_across.(everything(), as.character)
 #'
-#' example_dt %>%
-#'   mutate_across.(c(x, y), list(new = ~ .x * 2))
+#' test_df %>%
+#'   mutate_across.(c(x, y), list(new = ~ .x * 2,
+#'                                another = ~ .x + 7))
 mutate_if. <- function(.data, .predicate, .funs, ..., by = NULL) {
   UseMethod("mutate_if.")
 }
 
 #' @export
 mutate_if..default <- function(.data, .predicate, .funs, ..., by = NULL) {
-  .predicate <- enexpr(.predicate)
-  by <- enexpr(by)
 
-  mutate_across.(.data, !!.predicate, .funs, ..., by = !!by)
+  deprecate_soft("0.5.0", "tidytable::mutate_if.()", "mutate_across.()")
+
+  mutate_across.(.data, where({{.predicate}}), .funs, ..., by = {{by}})
 }
 
 #' @export
@@ -51,10 +52,10 @@ mutate_at. <- function(.data, .vars, .funs, ..., by = NULL) {
 
 #' @export
 mutate_at..default <- function(.data, .vars, .funs, ..., by = NULL) {
-  .vars <- enexpr(.vars)
-  by <- enexpr(by)
 
-  mutate_across.(.data, !!.vars, .funs, ..., by = !!by)
+  deprecate_soft("0.5.0", "tidytable::mutate_at.()", "mutate_across.()")
+
+  mutate_across.(.data, {{.vars}}, .funs, ..., by = {{by}})
 }
 
 #' @export
@@ -66,9 +67,9 @@ mutate_all. <- function(.data, .funs, ..., by = NULL) {
 #' @export
 mutate_all..default <- function(.data, .funs, ..., by = NULL) {
 
-  by <- enexpr(by)
+  deprecate_soft("0.5.0", "tidytable::mutate_all.()", "mutate_across.()")
 
-  mutate_across.(.data, everything.(), .funs, ..., by = !!by)
+  mutate_across.(.data, everything(), .funs, ..., by = {{by}})
 }
 
 #' @export
