@@ -3,35 +3,35 @@
 #' @description
 #' Rename variables from a data.table.
 #'
-#' @param .data A data.frame or data.table
+#' @param .df A data.frame or data.table
 #' @param ... Rename expression like dplyr::rename()
 #'
 #' @export
 #'
 #' @examples
-#' dt <- data.table::data.table(x = c(1,2,3), y = c(4,5,6))
+#' dt <- data.table(x = c(1,2,3), y = c(4,5,6))
 #'
 #' dt %>%
 #'   rename.(new_x = x,
 #'           new_y = y)
-rename. <- function(.data, ...) {
+rename. <- function(.df, ...) {
   UseMethod("rename.")
 }
 
 #' @export
-rename..data.frame <- function(.data, ...) {
+rename..data.frame <- function(.df, ...) {
 
-  .data <- as_tidytable(.data)
+  .df <- as_tidytable(.df)
 
-  dots <- enexprs(...)
-  .data <- shallow(.data)
+  dots <- enquos(...)
+  .df <- shallow(.df)
 
   new_names <- names(dots)
-  old_names <- as.character(dots)
+  old_names <- map_chr.(dots, quo_text)
 
-  setnames(.data, old_names, new_names)
+  setnames(.df, old_names, new_names)
 
-  .data
+  .df
 }
 
 #' @export
