@@ -12,7 +12,7 @@ test_that(".before and .after relocate individual cols", {
 
 test_that("can move blocks of variables", {
   df <- data.table(x = 1, a = "a", y = 2, b = "a")
-  expect_named(relocate.(df, is.character), c("a", "b", "x", "y"))
+  expect_named(relocate.(df, where(is.character)), c("a", "b", "x", "y"))
 })
 
 test_that("no .before/.after moves to front", {
