@@ -31,6 +31,17 @@ test_that("n.() works", {
   expect_equal(tidytable_df, datatable_df)
 })
 
+test_that(".GRP works", {
+  df <- tidytable(x = 1:4, y = c("a","a","a","b"))
+
+  tidytable_df <- df %>%
+    summarize.(count = .GRP, by = y)
+
+  datatable_df <- df[, list(count = .GRP), by = y]
+
+  expect_equal(tidytable_df, datatable_df)
+})
+
 test_that("can do group aggregation with no by", {
   df <- tidytable(x = 1:4, y = c("a","a","a","b"))
 
@@ -85,7 +96,7 @@ test_that("can do group aggregation with by enhanced selection", {
   df <- tidytable(x = 1:4, y = c("a","a","a","b"))
 
   tidytable_df <- df %>%
-    summarize.(avg_x = mean(x), by = is.character)
+    summarize.(avg_x = mean(x), by = where(is.character))
 
   datatable_df <- df[, list(avg_x = mean(x)), by = y]
 
@@ -115,3 +126,19 @@ test_that("can do group aggregation without by with data.frame", {
 
   expect_equal(tidytable_df, datatable_df)
 })
+
+test_that("can make a function with quosures", {
+  df <- tidytable(x = 1:4, y = c("a","a","a","b"))
+
+  summarize_fn <- function(.df, col) {
+    .df %>%
+      summarize.(avg_x = mean({{col}}), by = y)
+  }
+
+  tidytable_df <- df %>%
+    summarize_fn(x)
+
+  datatable_df <- df[, list(avg_x = mean(x)), by = y]
+
+  expect_equal(tidytable_df, datatable_df)
+})
